@@ -40,6 +40,13 @@
 #' @param value (`ANY`)\cr the new value.
 #' @param verbose (`flag`)\cr whether additional information should be displayed to the user. Defaults to `FALSE`.
 #' @param x (`ANY`)\cr an object.
+#' @param tt_type (`character(1)`)\cr One of "any", "row", "table", "elemtable";
+#'   when testing existence or resolving a path with "*" wildcards,
+#'   this indicates a restriction on *the final element the path resolves to*.
+#'   E.g., for "table", possible paths which match the structure of the
+#'   wild-card path but resolve to an individual row will not be considered matching.
+#'   The value "elemtable" indicates an Elementary table, i.e., one representing a
+#'   single variable within an `analyze` call.
 #'
 #' @return No return value.
 #'
@@ -49,7 +56,7 @@
 gen_args <- function(df, alt_counts_df, spl, pos, tt, tr, verbose, colwidths, obj, x,
                      value, object, path, label, label_pos, # visible_label,
                      cvar, topleft, page_prefix, hsep, indent_size, section_div, na_str, inset,
-                     table_inset,
+                     table_inset, tt_type = c("any", "row", "table", "elemtable"),
                      ...) {
   NULL
 }
@@ -127,6 +134,10 @@ gen_args <- function(df, alt_counts_df, spl, pos, tt, tr, verbose, colwidths, ob
 #' @param colcount_format (`character(1)`)\cr if `show_colcounts` is `TRUE`, the
 #'   format which should be used to display column counts for facets generated by
 #'   this split. Defaults to `"(N=xx)"`.
+#' @param parent_name (`character(1)`)\cr Name to assign to the table corresponding
+#'   to the *split* or *group of sibling analyses*, for `split_rows_by*` and
+#' `analyze*` when analyzing more than one variable, respectively. Ignored when
+#' analyzing a single variable.
 #'
 #' @inherit gen_args return
 #'
@@ -142,7 +153,7 @@ lyt_args <- function(lyt, var, vars, label, labels_var, varlabels, varnames, spl
                      var_labels, cvar,
                      table_names, topleft, align, page_by, page_prefix,
                      format_na_str, section_div, na_str, show_colcounts,
-                     colcount_format) {
+                     colcount_format, parent_name) {
   NULL
 }
 
