@@ -3,6 +3,7 @@
 #' This is a wrapper for [formatters::format_value()] for use with `CellValue` objects
 #'
 #' @inheritParams lyt_args
+#' @inheritParams formatters::format_value
 #' @param x (`CellValue` or `ANY`)\cr an object of class `CellValue`, or a raw value.
 #' @param format (`string` or `function`)\cr the format label or formatter function to
 #'   apply to `x`.
@@ -32,6 +33,7 @@ format_rcell <- function(x, format,
                          na_str = obj_na_str(x) %||% "NA",
                          pr_row_format = NULL,
                          pr_row_na_str = NULL,
+                         round_type = c("iec", "sas"),
                          shell = FALSE) {
   # Check for format and parent row format
   format <- if (missing(format)) obj_format(x) else format
@@ -50,6 +52,7 @@ format_rcell <- function(x, format,
   format_value(rawvalues(x),
     format = format,
     output = output,
-    na_str = na_str
+    na_str = na_str,
+    round_type = round_type
   )
 }
