@@ -205,6 +205,8 @@ setMethod(
     tt
   }
 )
+
+# nocov start
 #' @rdname insert_row_at_path
 setMethod(
   "insert_row_at_path", c("VTableTree", "ANY"),
@@ -217,6 +219,8 @@ setMethod(
   }
 )
 
+# nocov end
+
 #' Label at path
 #'
 #' Accesses or sets the label at a path.
@@ -302,6 +306,8 @@ setMethod(
 )
 
 # Recursive helper function to retrieve sub-tables from the tree
+## need to generalize this if we ever use it in a place other than tt_at_path
+## currently tt_at_path doesn't support "*"
 .extract_through_path <- function(cur_tbl, cur_path, no_stop = FALSE) {
   while (length(cur_path > 0)) {
     kids <- tree_children(cur_tbl)
@@ -310,20 +316,10 @@ setMethod(
     if (curname == "@content") {
       cur_tbl <- content_table(cur_tbl)
     } else if (curname %in% kids_names) {
-      cur_tbl <- kids[kids_names == curname]
-
-      # Case where there are more than one tree sub node with identical names
-      if (length(cur_tbl) > 1 && length(cur_path) > 1) {
-        cur_tbl <- sapply(cur_tbl, function(cti) .extract_through_path(cti, cur_path[-1], no_stop = TRUE))
-        found_values <- !sapply(cur_tbl, is.null)
-        cur_tbl <- cur_tbl[found_values]
-        if (sum(found_values) == 1) {
-          cur_tbl <- cur_tbl[[1]]
-        }
-        cur_path <- cur_path[1]
-      } else {
-        cur_tbl <- cur_tbl[[1]] # Usual case (only one matching value)
-      }
+      ## we're now guarnateed that there will only be one match
+      cur_tbl <- kids[kids_names == curname][[1]]
+    } else if (!no_stop && curname == "*") {
+      stop("Paths including '*' wildcards are not currently supported by tt_at_path.")
     } else if (!no_stop) {
       stop(
         "Path appears invalid for this tree at step '", curname, "'. Please use only",
@@ -337,6 +333,203 @@ setMethod(
   cur_tbl
 }
 
+tt_type_ok <- function(obj, type) {
+  switch(type,
+    any = TRUE,
+    row = is(obj, "TableRow"),
+    table = is(obj, "VTableTree"),
+    elemtable = is(obj, "ElementaryTable")
+  )
+}
+
+#' Pathing
+#'
+#' Pathing is a method of using known structure within a table
+#' to specify elements within it in a self-describing, semantically
+#' meaningful way.
+#'
+#' @details A Path consists of a character vector of one or more elements which
+#'    will be used to descend the tree structure of a table's row or column space.
+#'
+#' Existing paths will match the layout used to make the table in the form of
+#'    split, split-value pairs corresponding to facets generated by `split_rows_by*`
+#'    and, elementary subtables generated by `analyze`, and rows generated by the
+#'    afun used. Groups summaries generated by `summarize_row_groups` are represented
+#'    by the 'content table' attached to a subtable representing a facet generated
+#'    by a `split_rows_by` instruction, and are addressed via `@content` instead
+#'    of their name.
+#'
+#' For example, given the code
+#' \preformatted{
+#' lyt <- basic_table() |>
+#'   split_rows_by("ARM") |>
+#'   split_rows_by("RACE") |>
+#'   summarize_row_groups() |>
+#'   analyze("SEX") |>
+#'   analyze("AGE", nested = FALSE)
+#'
+#' tbl <- build_table(lyt, DM)
+#' }
+#'
+#' We know that there will be two top-level subtables, one representing
+#'   (and generated via) the split on the `ARM` variable, and one
+#'   generated from the non-nested analyze on `AGE`. These can be be
+#'   'pathed to' at `"ARM"` and `"AGE"`, respectively. Furthermore
+#'   each value for `ARM` can be pathed to via, e.g.,  `c("ARM", "A: Drug X")`
+#'   or more generally using the pathing wildcard `"*"` at `c("ARM", "*")`.
+#'
+#' A particular `SEX` analysis subtable, then, would be pathed to via the
+#'   (row) path `c("ARM", "*", "RACE", "*", "SEX")`, e.g.
+#'   `c("ARM", "B: Placebo", "RACE", "ASIAN", "SEX")`. The group-summary for
+#'   Asians within the placebo group would be pathed to via
+#'   `c("ARM", "B: Placebo", "RACE", "ASIAN", "@content")` for the table, and
+#'   `c("ARM", "B: Placebo", "RACE", "ASIAN", "@content", "ASIAN")` for the
+#'   row.
+#'
+#' @note some pathing-based functionality supports the "*" wildcard (typically
+#'   'setters'/functionality which alters a table and returns it) while some
+#'   does not (typically 'getters' which retrieve a subtable/row from a table
+#'   or some attribute of that subtable/row).
+#'
+#' @note The `"*"` wildcard will never act as `"@content"` to step into
+#'   a subtable's content table; that must be specified in the path, via
+#'   e.g., `c("*", "*", "@content")` instead of `c("*", "*", "*")`.
+#'
+#' @description for `tt_row_path_exists`, tests whether a single path (potentially
+#'    including `"*"` wildcards) resolves to at least one element satisfying
+#'    `tt_type` (if specified).
+#' @inheritParams gen_args
+#' @return For `tt_row_path_exists`: `TRUE` if the path resolves to at least one
+#'     substructure (subtable or row) that satisfies `tt_type`, or if the
+#'     path is length 0; `FALSE` otherwise
+#' @export
+#' @examples
+#' lyt <- basic_table() |>
+#'   split_rows_by("ARM") |>
+#'   split_rows_by("STRATA1") |>
+#'   analyze("SEX") |>
+#'   analyze("SEX", nested = FALSE)
+#' tbl <- build_table(lyt, DM)
+#' tt_row_path_exists(tbl, c("root", "ARM", "*", "*", "*", "SEX")) # TRUE
+#' tt_row_path_exists(tbl, c("ARM", "*", "*", "*", "SEX")) # TRUE
+#' tt_row_path_exists(tbl, c("ARM", "*", "*", "SEX")) # FALSE
+#' tt_row_path_exists(tbl, "FAKE") # FALSE
+#' tt_row_path_exists(tbl, c("ARM", "*", "STRATA1", "*", "SEX")) # TRUE
+#' tt_row_path_exists(tbl, c("ARM", "*", "STRATA", "*", "SEX")) # FALSE
+#' tt_row_path_exists(tbl, "SEX") # TRUE
+#' tt_row_path_exists(tbl, "SEX", tt_type = "table") # TRUE
+#' tt_row_path_exists(tbl, "SEX", tt_type = "elemtable") # TRUE
+#' tt_row_path_exists(tbl, "SEX", tt_type = "row") # FALSE
+#' tt_row_path_exists(tbl, c("SEX", "*")) # TRUE
+tt_row_path_exists <- function(obj, path, tt_type = c("any", "row", "table", "elemtable")) {
+  tt_type <- match.arg(tt_type)
+  if (length(path) == 0) {
+    ## we matched everything and called it again, evaluate type condition and return answer
+    return(tt_type_ok(obj, tt_type))
+  } else if (length(path) > 1 && (is.null(obj) || is(obj, "TableRow"))) {
+    ## we got to a leaf node but still have >1 step remaining, path doesn't exist
+    return(FALSE)
+  }
+
+  if (path[1] == "root") {
+    path <- path[-1]
+  }
+  if (length(path) > 0 && path[1] == obj_name(obj)) {
+    path <- path[-1] ## character()[-1] is just character() again so this is ok
+  }
+
+  ## annoying we have to do this again :-/
+  if (length(path) == 0) {
+    ## we matched everything and called it again, evaluate type condition and return answer
+    return(tt_type_ok(obj, tt_type))
+  }
+  kids <- tree_children(obj)
+  kidnms <- vapply(kids, obj_name, "")
+  curpth <- path[1]
+  nextpth <- path[-1]
+  if (curpth == "*") {
+    ret <- any(vapply(kids, tt_row_path_exists, path = nextpth, tt_type = tt_type, TRUE))
+  } else if (curpth == "@content") {
+    ctab <- content_table(obj)
+    if (NROW(ctab) == 0) {
+      return(FALSE)
+    }
+    ret <- tt_row_path_exists(ctab, nextpth, tt_type = tt_type)
+  } else if (curpth %in% kidnms) {
+    ret <- tt_row_path_exists(kids[[curpth]], nextpth, tt_type = tt_type)
+  } else {
+    ret <- FALSE
+  }
+  ret
+}
+
+#' @rdname tt_row_path_exists
+#' @param .prev_path (`character`)\cr Internal implementation detail.
+#'     Do not set manually.
+#' @description Given a path with at least one wildcard (`"*"`) in it,
+#'     `tt_normalize_path` walks the tree and generates the complete
+#'     set of fully specified (ie no wildcards) paths which exist in
+#'     the row structure of `obj`
+#' @return for `tt_normalize_row_path`: a list of 0 or more fully
+#'     specified paths which exist in the row structure of `obj` that
+#'     match the original wildcard path, and which lead to an element
+#'     of type `tt_type` (if specified other than `"any")`.
+#' @export
+#' @aliases pathing
+#' @examples
+#' tt_normalize_row_path(tbl, c("root", "ARM", "*", "*", "*", "SEX"))
+#' tt_normalize_row_path(tbl, "SEX", tt_type = "row") # empty list
+tt_normalize_row_path <- function(obj,
+                                  path,
+                                  .prev_path = character(),
+                                  tt_type = c("any", "row", "table", "elemtable")) {
+  if (length(path) == 0) {
+    return(list(.prev_path))
+  }
+  tt_type <- match.arg(tt_type)
+  if (!tt_row_path_exists(obj, path, tt_type = tt_type)) {
+    return(list())
+  }
+  wcpos <- grep("^[*]$", path)
+  if (length(wcpos) == 0) {
+    return(list(c(.prev_path, path)))
+  }
+
+  befwc <- path[seq_len(wcpos[1] - 1)]
+  if (length(befwc) > 0) {
+    subtbl <- tt_at_path(obj, befwc)
+  } else {
+    subtbl <- obj
+  }
+  kids <- tree_children(subtbl)
+
+  nextstps <- names(kids)
+  aftrwc <- tail(path, -1 * wcpos[1])
+  if (tt_type != "any") {
+    if (length(aftrwc) > 0) {
+      keep <- vapply(nextstps, function(nm) tt_row_path_exists(kids[[nm]], aftrwc, tt_type = tt_type), TRUE)
+    } else {
+      keep <- vapply(kids, tt_type_ok, tt_type = tt_type, TRUE)
+    }
+    nextstps <- nextstps[keep]
+    if (length(nextstps) == 0) {
+      return(list())
+    }
+    kids <- kids[keep]
+  }
+  unlist(
+    recursive = FALSE,
+    lapply(
+      kids,
+      function(kdi) {
+        tt_normalize_row_path(kdi, path = aftrwc, .prev_path = c(.prev_path, befwc, obj_name(kdi)))
+      }
+    )
+  )
+}
+
+## XXX TODO some other day tt_normalize_col_path
+
 #' @note Setting `NULL` at a defined path removes the corresponding sub-table.
 #'
 #' @examples
@@ -650,7 +843,33 @@ setMethod(
 
 ## we have two options here: path like we do with rows and positional
 ## in leaf space.
-
+#' Subset a table or row to particular columns
+#' @inheritParams gen_args
+#' @inheritParams brackets
+#' @inheritParams head
+#' @param j (`integer`, `logical` or `character`)\cr The column(s) to subset `tt`
+#'   down to. Character vectors are interpreted as a *column path*, not as names.
+#'   Path can include `"*"` wildcards.
+#' @param newcinfo (`NULL` or `InstantiatedColumnInfo`)\cr The new column info,
+#'   if precomputed. Generally should not be manually set by users.
+#' @param ... Ignored.
+#'
+#' @examples
+#' lyt <- basic_table(
+#'   title = "Title",
+#'   subtitles = c("Sub", "titles"),
+#'   prov_footer = "prov footer",
+#'   main_footer = "main footer"
+#' ) %>%
+#'   split_cols_by("ARM") %>%
+#'   split_cols_by("SEX") %>%
+#'   analyze(c("AGE"))
+#'
+#' tbl <- build_table(lyt, DM)
+#'
+#' subset_cols(tbl, c(1, 3))
+#' subset_cols(tbl, c("ARM", "*", "SEX", "F"))
+#' @export
 setGeneric(
   "subset_cols",
   function(tt,
@@ -664,6 +883,8 @@ setGeneric(
   }
 )
 
+#' @exportMethod subset_cols
+#' @rdname subset_cols
 setMethod(
   "subset_cols", c("TableTree", "numeric"),
   function(tt, j, newcinfo = NULL,
@@ -696,6 +917,8 @@ setMethod(
   }
 )
 
+#' @exportMethod subset_cols
+#' @rdname subset_cols
 setMethod(
   "subset_cols", c("ElementaryTable", "numeric"),
   function(tt, j, newcinfo = NULL,
@@ -738,8 +961,11 @@ setMethod(
 
 path_collapse_sep <- "`"
 escape_name_padding <- function(x) {
-  ret <- gsub("._[[", "\\._\\[\\[", x, fixed = TRUE)
-  ret <- gsub("]]_.", "\\]\\]_\\.", ret, fixed = TRUE)
+  ##  ret <- gsub("._[[", "\\._\\[\\[", x, fixed = TRUE)
+  ##  ret <- gsub("]]_.", "\\]\\]_\\.", ret, fixed = TRUE)
+  ret <- gsub("[", "\\[", x, fixed = TRUE)
+  ret <- gsub("]", "\\]", ret, fixed = TRUE)
+  ret <- gsub(".", "\\.", ret, fixed = TRUE)
   ret
 }
 path_to_regex <- function(path) {
@@ -828,6 +1054,8 @@ select_cells_j <- function(cells, j) {
   }, cl = retcells, sp = newspans, SIMPLIFY = FALSE)
 }
 
+#' @exportMethod subset_cols
+#' @rdname subset_cols
 setMethod(
   "subset_cols", c("ANY", "character"),
   function(tt, j, newcinfo = NULL, keep_topleft = TRUE, ...) {
@@ -836,6 +1064,8 @@ setMethod(
   }
 )
 
+#' @exportMethod subset_cols
+#' @rdname subset_cols
 setMethod(
   "subset_cols", c("TableRow", "numeric"),
   function(tt, j, newcinfo = NULL, keep_topleft = TRUE, ...) {
@@ -855,6 +1085,8 @@ setMethod(
   }
 )
 
+#' @exportMethod subset_cols
+#' @rdname subset_cols
 setMethod(
   "subset_cols", c("LabelRow", "numeric"),
   function(tt, j, newcinfo = NULL, keep_topleft = TRUE, ...) {
@@ -868,6 +1100,8 @@ setMethod(
   }
 )
 
+#' @exportMethod subset_cols
+#' @rdname subset_cols
 setMethod(
   "subset_cols", c("InstantiatedColumnInfo", "numeric"),
   function(tt, j, newcinfo = NULL, keep_topleft = TRUE, ...) {
@@ -892,6 +1126,8 @@ setMethod(
   }
 )
 
+#' @exportMethod subset_cols
+#' @rdname subset_cols
 setMethod(
   "subset_cols", c("LayoutColTree", "numeric"),
   function(tt, j, newcinfo = NULL, ...) {
@@ -1116,6 +1352,20 @@ setMethod(
   }
 )
 
+#' @exportMethod [
+#' @rdname int_methods
+#' @keywords internal
+setMethod(
+  "[", c("VTableTree", "character", "missing"),
+  function(x, i, j, ..., drop = FALSE) {
+    ## i <- .path_to_pos(i, seq_len(nrow(x)), x, NROW)
+    j <- seq_len(ncol(x))
+    i <- .path_to_pos(i, x)
+    x[i = i, j = j, ..., drop = drop]
+  }
+)
+
+
 ## to avoid dispatch ambiguity. Not necessary, possibly not a good idea at all
 #' @exportMethod [
 #' @rdname int_methods
