@@ -1,7 +1,7 @@
-## ---- echo=FALSE--------------------------------------------------------------
-knitr::opts_chunk$set(comment = "")
+## ----echo=FALSE---------------------------------------------------------------
+knitr::opts_chunk$set(comment = "#")
 
-## ---- message=FALSE-----------------------------------------------------------
+## ----message=FALSE------------------------------------------------------------
 library(rtables)
 
 ## -----------------------------------------------------------------------------
